# ChatDefaultTaskResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**task_id** | **str** |  | 

## Example

```python
from arthur_observability_sdk._generated.models.chat_default_task_response import ChatDefaultTaskResponse

# TODO update the JSON string below
json = "{}"
# create an instance of ChatDefaultTaskResponse from a JSON string
chat_default_task_response_instance = ChatDefaultTaskResponse.from_json(json)
# print the JSON string representation of the object
print(ChatDefaultTaskResponse.to_json())

# convert the object into a dict
chat_default_task_response_dict = chat_default_task_response_instance.to_dict()
# create an instance of ChatDefaultTaskResponse from a dict
chat_default_task_response_from_dict = ChatDefaultTaskResponse.from_dict(chat_default_task_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


